Example code from tree-sitter tutorials.
First, clone [https://github.com/tree-sitter/tree-sitter.githttps://github.com/tree-sitter/tree-sitter.git](https://github.com/tree-sitter/tree-sitter.git) and [https://github.com/tree-sitter/tree-sitter-json.git](https://github.com/tree-sitter/tree-sitter-json.git).
Build tree-sitter project.
Run the examples using the bash scripts.